"""constants.py - Miscellaneous constants."""

import os

import portability

VERSION = '4.0.3'
HOME_DIR = portability.get_home_directory()
CONFIG_DIR = portability.get_config_directory()
DATA_DIR = portability.get_data_directory()
